@@ -33,9 +33,11 @@ from plone.i18n.normalizer import idnormalizer
 from plone.memoize import forever
 from plone.memoize.instance import memoize
 from plone.memoize.view import memoize_contextless
+from plone.registry.interfaces import IRegistry
 from plonetheme.nuplone.utils import isAnonymous
 from Products.CMFCore.interfaces import ISiteRoot
 from Products.CMFCore.utils import getToolByName
+from Products.CMFPlone.interfaces import ISecuritySchema
 from Products.Five import BrowserView
 from Products.statusmessages.interfaces import IStatusMessage
 from six.moves.urllib.parse import urlencode
@@ -143,6 +145,13 @@ class WebHelpers(BrowserView):
             "euphorie.allow_guest_accounts", default=False
         )
 
+    @property
+    @memoize
+    def allow_self_registration(self):
+        registry = getUtility(IRegistry)
+        security_settings = registry.forInterface(ISecuritySchema, prefix="plone")
+        return security_settings.enable_self_reg
+
     @property
     @memoize
     def use_involve_phase(self):
@@ -763,8 +772,11 @@ class WebHelpers(BrowserView):
     def timezoned_date(self, mydate=None):
         if mydate is None:
             return None
-        utc = tz.gettz(self.server_timezone)
-        return mydate.replace(tzinfo=utc)
+        # If the date already has a timezone, don't touch it
+        if mydate.tzinfo is not None:
+            return mydate
+        local_tz = tz.gettz(self.server_timezone)
+        return mydate.replace(tzinfo=local_tz)
 
     @property
     @memoize
@@ -917,6 +929,17 @@ class WebHelpers(BrowserView):
         """In plain Euphorie, the logo is always shown"""
         return True
 
+    @property
+    @memoize
+    def portal_transforms(self):
+        return api.portal.get_tool("portal_transforms")
+
+    def get_safe_html(self, text):
+        data = self.portal_transforms.convertTo(
+            "text/x-html-safe", text, mimetype="text/html"
+        )
+        return data.getData()
+
     @property
     @memoize
     def custom_js(self):
