@@ -7,12 +7,17 @@ from euphorie.testing import EuphorieIntegrationTestCase
 from plone import api
 from zExceptions import Unauthorized
 
-import mock
+
+try:
+    from unittest import mock
+except ImportError:
+    import mock
 
 
 class TestArchivingViews(EuphorieIntegrationTestCase):
     def setUp(self):
         super(TestArchivingViews, self).setUp()
+        self.loginAsPortalOwner()
         addSurvey(self.portal, BASIC_SURVEY)
         self.account = addAccount(password="secret")
         survey_session = model.SurveySession(
