@@ -14,14 +14,22 @@ a catalog indexer which returns a plain text version of the description.
 from euphorie.content import MessageFactory as _
 from euphorie.content.utils import StripMarkup
 from plone.app.z3cform.wysiwyg import WysiwygFieldWidget
-from plone.directives import form
+from plone.autoform import directives
 from plone.indexer import indexer
+from plone.supermodel import model
 from zope import schema
 
-import HTMLParser
+
+try:
+    from html import unescape
+except ImportError:
+    # PY2
+    import HTMLParser
+
+    unescape = HTMLParser.HTMLParser().unescape
 
 
-class IRichDescription(form.Schema):
+class IRichDescription(model.Schema):
     """Simple behaviour for content types with a HTML description.
     Replaces the standard description field with a rich text version.
     """
@@ -31,8 +39,8 @@ class IRichDescription(form.Schema):
         description=_(u"A short summary of the content."),
         required=False,
     )
-    form.widget(description=WysiwygFieldWidget)
-    form.order_after(description="title")
+    directives.widget(description=WysiwygFieldWidget)
+    directives.order_after(description="title")
 
 
 @indexer(IRichDescription)
@@ -44,5 +52,4 @@ def Description(obj):
     if d is None:
         return None
 
-    h = HTMLParser.HTMLParser()
-    return h.unescape(StripMarkup(d))
+    return unescape(StripMarkup(d))
