@@ -1,19 +1,16 @@
+# coding=utf-8
 from .. import MessageFactory as _
 from euphorie.content.behaviour.richdescription import IRichDescription
 from euphorie.content.utils import StripMarkup
-from five import grok
 from htmllaundry.z3cform import HtmlText
 from plone.app.dexterity.behaviors.metadata import IBasic
 from plone.app.z3cform.wysiwyg import WysiwygFieldWidget
-from plone.directives import form
+from plone.autoform import directives
 from plone.indexer import indexer
-from plonetheme.nuplone.skin.interfaces import NuPloneSkin
+from plone.supermodel import model
 
 
-grok.templatedir("templates")
-
-
-class IPage(form.Schema, IRichDescription, IBasic):
+class IPage(model.Schema, IRichDescription, IBasic):
     """A basic page."""
 
     description = HtmlText(
@@ -25,21 +22,13 @@ class IPage(form.Schema, IRichDescription, IBasic):
         ),
         required=True,
     )
-    form.widget(description=WysiwygFieldWidget)
-    form.order_after(description="title")
+    directives.widget(description=WysiwygFieldWidget)
+    directives.order_after(description="title")
 
     body = HtmlText(title=_("label_body", u"Page content"), required=True)
-    form.widget(body=WysiwygFieldWidget)
+    directives.widget(body=WysiwygFieldWidget)
 
 
 @indexer(IPage)
 def SearchableTextIndexer(obj):
     return " ".join([obj.title, StripMarkup(obj.description), StripMarkup(obj.body)])
-
-
-class View(grok.View):
-    grok.context(IPage)
-    grok.require("zope2.View")
-    grok.layer(NuPloneSkin)
-    grok.template("page_view")
-    grok.name("nuplone-view")
